<?php
/*
Plugin Name: Floating Admin Button
Plugin URI: http://cagewebdev.com/floating-admin-button
Description: On frontend pages this plugin shows a floating admin button instead of the admin bar
Version: 1.1.2
Date: 07/25/2016
Author: Rolf van Gelder
Author URI: http://cagewebdev.com
License: GPLv2 or later
*/
?>
<?php
if (!session_id()) session_start();
?>
<?php
/***********************************************************************************
 * 	MAIN CLASS
 ***********************************************************************************/	 
class Fab
{
	var $fab_version       = '1.1.2';
	var $fab_release_date  = '07/25/2016';
	var $fab_plugin_page   = 'http://cagewebdev.com/floating-admin-button/';
	var $fab_download_page = 'https://wordpress.org/plugins/floating-admin-button/';
	var $fab_donation_page = 'http://cagewebdev.com/donations-fab/';
	
	var $fab_minified      = '';
	var $fab_text_domain   = 'floating-admin-button';
	
	/*******************************************************************************
	 * 	CONSTRUCTOR
	 *******************************************************************************/
	function __construct()
	{
		// USE THE NON-MINIFIED VERSION WHILE DEBUGGING
		$this->fab_minified = (defined('WP_DEBUG') && WP_DEBUG) ? '' : '.min';		
		
		// INITIALIZE PLUGIN
		add_action('init', array(&$this, 'fab_init'));
				
		// GET OPTIONS FROM DB (JSON FORMAT)
		$this->fab_options = get_option('fab_options');

		// INITIALIZE SETTINGS
		$this->fab_init_settings();

		// BASE NAME OF THE PLUGIN
		$this->plugin_basename = plugin_basename(__FILE__);
		$this->plugin_basename = substr($this->plugin_basename, 0, strpos( $this->plugin_basename, '/'));
		
		// IMAGE LOCATION
		$this->imgurl = plugins_url().'/'.$this->plugin_basename.'/images/';
		$this->imgdir = plugin_dir_path( __FILE__ ).'images/';
		
		// LOCALIZATION
		add_action('init', array(&$this, 'fab_i18n'));		
		
		// ADD STYLE SHEET(S)
		add_action('init', array(&$this, 'fab_styles'));

	} // __construct()


	/*******************************************************************************
	 * 	INITIALIZE PLUGIN
	 *******************************************************************************/
	function fab_init()
	{
		if(!is_user_logged_in()) return;

		// USER IS LOGGED IN
		if($this->fab_is_frontend_page())
		{	// FRONTEND PAGE - ADD FRONTEND SCRIPTS TO FOOTER
			add_action('wp_footer', array(&$this, 'fab_fe_scripts'));			
		}
		else
		{	// BACKEND PAGE
			// ADD PAGE TO ADMIN MENU
			add_action('admin_menu', array(&$this, 'fab_admin_menu'));
			// ADD LINK TO SETTINGS PAGE ON THE MAIN PLUGIN PAGE
			add_filter('plugin_action_links_'.plugin_basename(__FILE__), array(&$this, 'fab_settings_link'));
			if ($this->fab_is_relevant_page())
				// LOAD JAVASCRIPT ONLY ON RELEVANT BACKEND PAGE(S)
				add_action('admin_enqueue_scripts', array(&$this, 'fab_be_scripts'));
		} // if($this->fab_is_frontend_page() && is_user_logged_in())
	} // fab_init()
	
	
	/*******************************************************************************
	 * 	INITIALIZE SETTINGS (FIRST RUN)
	 *******************************************************************************/
	function fab_settings()
	{	// INITIALIZE SETTINGS (FIRST RUN)
		include_once(trailingslashit(dirname( __FILE__ )).'/admin/settings.php');
	} // fab_settings()	
	

	/*******************************************************************************
	 * 	INITIALIZE SETTINGS
	 *******************************************************************************/
	function fab_init_settings()
	{	// SET DEFAULTS (IF MEEDED)
		$changed = false;
		if(!isset($this->fab_options['initial_button']))
		{	$this->fab_options['initial_button'] = 'Y';
			$changed = true;
		}
		if(!isset($this->fab_options['button_enabled']))
		{	$this->fab_options['button_enabled'] = 'Y';
			$changed = true;
		}
		if(!isset($this->fab_options['shift_ctrl']))
		{	$this->fab_options['shift_ctrl']     = 'ctrl';
			$changed = true;
		}
		if(!isset($this->fab_options['keycode']))
		{	$this->fab_options['keycode']        = '119'; // F8
			$changed = true;
		}
		if(!isset($this->fab_options['position']))
		{	$this->fab_options['position']       = 'lowerleft';
			$changed = true;
		}
		if(!isset($this->fab_options['horz_spacing']))
		{	$this->fab_options['horz_spacing']   = '20px';
			$changed = true;
		}
		if(!isset($this->fab_options['vert_spacing']))
		{	$this->fab_options['vert_spacing']   = '20px';
			$changed = true;
		}
		if(!isset($this->fab_options['scrolltext']))
		{	$this->fab_options['scrolltext']     = 'Open Admin Screen';
			$changed = true;
		}
		if(!isset($this->fab_options['adminurl']))
		{	$this->fab_options['adminurl']       = admin_url();
			$changed = true;
		}

		// SAVE OPTIONS ARRAY
		if($changed) update_option('fab_options', $this->fab_options);
	} // fab_init_settings()
	

	/*******************************************************************************
	 * 	DEFINE TEXT DOMAIN (FOR LOCALIZATION)
	 *******************************************************************************/
	function fab_i18n()
	{	load_plugin_textdomain($this->fab_text_domain, false, dirname(plugin_basename( __FILE__ )).'/language/');
	} // fab_action_init()	
	
	
	/*******************************************************************************
	 * 	LOAD STYLESHEET(S)
	 *******************************************************************************/
	function fab_styles()
	{
		if(($this->fab_is_frontend_page() || $this->fab_is_relevant_page()) && is_user_logged_in())
		{	// FRONTEND PAGE OR RELEVANT BACKEND PAGE
			wp_register_style('fab-style', plugins_url('css/floating-admin-button'.$this->fab_minified.'.css', __FILE__));
			wp_enqueue_style('fab-style');		
		}
	} // fab_styles()


	/*******************************************************************************
	 * 	IS THIS A FRONTEND PAGE?
	 *******************************************************************************/
	function fab_is_frontend_page()
	{	if (isset($GLOBALS['pagenow']))
			return !is_admin() && !in_array($GLOBALS['pagenow'], array('wp-login.php', 'wp-register.php'));
		else
			return !is_admin();
	} // fab_is_frontend_page()
	
	
	/*******************************************************************************
	 * 	ARE WE ON A, FOR THIS PLUGIN, RELEVANT BACKEND PAGE?
	 *******************************************************************************/	
	function fab_is_relevant_page()
	{
		$this_page = '';
		if(isset($_GET['page'])) $this_page = $_GET['page'];	
		return ($this_page == 'fab_settings');
	} // fab_is_relevant_page()	
	

	/*******************************************************************************
	 * 	ADD PAGE TO THE SETTINGS MENU
	 *******************************************************************************/
	function fab_admin_menu()
	{	if (function_exists('add_options_page'))
		{	global $fab_options;
			$fab_options = add_options_page(__('Floating Admin Button', $this->fab_text_domain), __( 'Floating Admin Button', $this->fab_text_domain ), 'manage_options', 'fab_settings', array( &$this, 'fab_settings'));
		}
	} // fab_admin_menu()
	
	
	/*******************************************************************************
	 * 	ADD 'SETTINGS' LINK TO THE MAIN PLUGIN PAGE
	 *******************************************************************************/
	function fab_settings_link($links)
	{	array_unshift($links, '<a href="options-general.php?page=fab_settings">Settings</a>');
		return $links;
	} // fab_settings_link()
	
	
	/*******************************************************************************
	 * 	LOAD FRONTEND JAVASCRIPT
	 *******************************************************************************/
	function fab_fe_scripts()
	{	// true: in footer
		wp_enqueue_script('fab-active', plugin_dir_url( __FILE__ ).'js/floating-admin-button-fe'.$this->fab_minified.'.js', array('jquery', 'jquery-ui-draggable'), $this->fab_version, true);
		// WRITE JAVASCRIPT VARIABLES
		wp_localize_script('fab-active', 'fab', $this->fab_get_javascript_vars());
	} // fab_fe_scripts()
	
	
	/*******************************************************************************
	 * 	LOAD BACKEND JAVASCRIPT
	 *******************************************************************************/
	function fab_be_scripts()
	{	// false: in header
		wp_register_script('fab-backend', plugins_url('js/floating-admin-button-be'.$this->fab_minified.'.js', __FILE__), array('jquery'), $this->fab_version, false);		
		wp_enqueue_script('fab-backend');
	} // fab_be_scripts()
	
	
	/*******************************************************************************
	 * 	PASS SETTINGS TO JAVASCRIPT
	 *******************************************************************************/
	function fab_get_javascript_vars()
	{
		$fab_initial_button = $this->fab_options['initial_button'];
		if(isset($_SESSION['fab_initial_button'])) $fab_initial_button = $_SESSION['fab_initial_button'];		

		// BUTTON HAS BEEN DRAGGED DURING THIS SESSION?
		$fab_bottom = -1;
		if(isset($_SESSION['fab_bottom'])) $fab_bottom = $_SESSION['fab_bottom'];
		$fab_left   = -1;
		if(isset($_SESSION['fab_left']))   $fab_left   = $_SESSION['fab_left'];

		// STRIP THE 'px': '100px' => '100'
		$fab_horz_spacing_int = substr($this->fab_options['horz_spacing'], 0, strlen($this->fab_options['horz_spacing']) - 2);
		$fab_vert_spacing_int = substr($this->fab_options['vert_spacing'], 0, strlen($this->fab_options['vert_spacing']) - 2);

		// URL FOR THE AJAX SERVER (NEEDED FOR FRONTEND OPERATION, ajaxurl DOESN'T WORK ON THE FRONTEND)
		$fab_ajax_url  = admin_url('admin-ajax.php');
		//$fab_admin_url = admin_url();
		
		// RETURN THE ARRAY WITH JAVASCRIPT VARIABLES
		return array(
			'initial_button'   => $fab_initial_button,
			'button_enabled'   => $this->fab_options['button_enabled'],
			'shift_ctrl'       => $this->fab_options['shift_ctrl'],
			'keycode'          => $this->fab_options['keycode'],
			'position'         => $this->fab_options['position'],
			'bottom'           => $fab_bottom,
			'left'             => $fab_left,
			'horz_spacing'     => $this->fab_options['horz_spacing'],
			'horz_spacing_int' => $fab_horz_spacing_int,
			'vert_spacing'     => $this->fab_options['vert_spacing'],
			'vert_spacing_int' => $fab_vert_spacing_int,
			'scrolltext'       => $this->fab_options['scrolltext'],
			'imgurl'           => $this->imgurl.'wp_logo.png',
			'ajaxurl'          => $fab_ajax_url,
			'adminurl'         => $this->fab_options['adminurl']
		);		
	} // fab_get_javascript_vars()
} // Fab

// CREATE INSTANCE
global $fab_class;
$fab_class = new Fab;


/*******************************************************************************
 * 	AJAX SERVER FOR UPDATING THE CURRENT BUTTON POSITION
 *******************************************************************************/
function fab_action_callback()
{
	if(isset($_POST['fab_action']))
	{
		$action = sanitize_text_field($_POST['fab_action']);
		
		// SAVE THE CURRENT BUTTON POSITION TO SESSION VARIABLES
		if($action == 'set_position')
		{
			$_SESSION['fab_bottom'] = sanitize_text_field($_POST['fab_bottom']);
			$_SESSION['fab_left']   = sanitize_text_field($_POST['fab_left']);
		}
		else if ($action == 'set_initial_button')
		{	// v1.0.6
			$_SESSION['fab_initial_button'] = sanitize_text_field($_POST['fab_initial_button']);
		}
		else if ($action == 'reset_position')
		{
			unset($_SESSION['fab_bottom']);
			unset($_SESSION['fab_left']);
		}
		
		if(isset($_POST['fab_bottom'])) echo $_POST['fab_bottom'];
	} // if(isset($_POST['fab_action']))

	// NEEDED FOR AN AJAX SERVER
	wp_die();
} // fab_action_callback()

// ADD AJAX SERVER
add_action( 'wp_ajax_fab_action', 'fab_action_callback' );
?>